@@ -2,6 +2,8 @@ from typing import Tuple, Union
 
 from PIL import ImageFont
 
+from .color import Color
+from .font import Font
 
 class Text:
     """Text class
@@ -12,16 +14,21 @@ class Text:
         Text
     font : ImageFont.FreeTypeFont
         Font for text
-    color : Union[Tuple[int, int, int], str, int], optional
+    color : Color, optional
         Font color, by default "black"
     """
 
     def __init__(
         self,
         text: str,
-        font: ImageFont.FreeTypeFont,
-        color: Union[Tuple[int, int, int], str, int] = "black",
+        font: Union[ImageFont.FreeTypeFont, Font],
+        color: Color = "black",
     ) -> None:
         self.text = text
-        self.font = font
         self.color = color
+
+        if isinstance(font, Font):
+            self.font = font.font
+        else:
+            self.font = font
+            
\ No newline at end of file
